<?
	//-------------------------------------------------------------------------------------
	/*
		Validate date format via ereg
	
		delimeter can be either . / or - 
		URL: http://www.phpbuilder.com/forum/read.php3?num=2&id=121666&loc=0&thread=121634
		
		sample:
		include("lib/date_time.lib.php");
		
		if ($d = validate_date("28.12.2002"))
		{
			echo $d["day"] . "." . $d["month"] . "." . $d["year"] . "<br>";
			echo "ok";
		}
			else
				echo "no date";
	*/
	//-------------------------------------------------------------------------------------
	function validate_date( $date, $min_year = 1, $max_year = 32767) 
	{ 
		//$format = "([0-9]{4})[-\/]([0-9]{1,2})[-\/]([0-9]{1,2})"; 	// US e.g. 2002/12/30 or 2002-12-30
		$format = "([0-9]{1,2})[.\/-]([0-9]{1,2})[.\/-]([0-9]{4})"; 	// DE Format: tt.mm.tttt  e.g. 30.12.2002 or 30-12-2002 or 30/12/2002
		
		if (ereg($format, $date, $val)) 
		{ 
			if ($val[3] >= $min_year && $val[3] <= $max_year) 
			{
				if(checkdate ($val[2], $val[1], $val[3]))
				{
					$_ret["year"]	= $val[3];
					$_ret["month"]	= $val[2];
					$_ret["day"]	= $val[1];
					return $_ret;
				}
			}
		}
		return false; // bad year 		
	} 

	//-------------------------------------------------------------------------------------
	/*
		Validate time format via ereg
	
	 	delimeter can be ":"
	
		sample:
		include("lib/date_time.lib.php");
		
		if($t = validate_time("23:21:2"))
		{
			echo $t["hour"] . ":" . $t["minute"] . ":" . $t["second"] . "<br>";
			echo "ok";
		}
		else
			echo "no time";
	
	*/
	//-------------------------------------------------------------------------------------
	function validate_time($t) 
	{ 
		$format_1 = "([0-9]{1,2})[:]([0-9]{1,2})[:]([0-9]{1,2})"; 	// DE Format: hh:mm:ss
		$format_2 = "([0-9]{1,2})[:]([0-9]{1,2})"; 	// DE Format: hh:mm
		
		if (ereg($format_1, $t, $val)) // with seconds
		{
			if ($val[1] >= 0 && $val[1] <= 23 && $val[2] >= 0 && $val[2] <= 59 && $val[3] >= 0 && $val[3] <= 59) 
			{
				$_ret["hour"]		= $val[1];
				$_ret["minute"]	= $val[2];
				$_ret["second"]	= $val[3];
				return $_ret;
			}	
		}
		else
		{
			if (ereg($format_2, $t, $val)) // without seconds
			{
				if ($val[1] >= 0 && $val[1] <= 23 && $val[2] >= 0 && $val[2] <= 59) 
				{
					$_ret["hour"]		= $val[1];
					$_ret["minute"]	= $val[2];
					$_ret["second"]	= NULL;
					return $_ret;
				}
			}
		}
		return false;
	}
	
	
	//-------------------------------------------------------------------------------------
	/*
		 DateDiff, according to the documentation
		"Returns the number of intervals between two dates". 
		URL: http://www.phpbuilder.com/columns/akent20000610.php3?page=7
		
		The syntax is DateDiff(interval,date1,date2). 
	
		The intervals that it uses are the same as those that we saw in the
		DateAdd function. For the sake of simplicity we're going to gloss over 
		a number of elements of VBScipt's DateDiff function that would otherwise 
		complicate matters. In this example the optional arguments to DateDiff 
		(that is whether the week starts on a Monday or a Sunday) are not used. 
		The intervals that we are going to allow are going to be "w", "d", "h", "n" and "s". 
	*/
	//-------------------------------------------------------------------------------------
	function date_diff ($interval, $date1, $date2)
	{

    	// get the number of seconds between the two dates
		$timedifference =  $date2 - $date1;
    
		 switch ($interval)
		 {
			  case "w":
					$retval  = bcdiv($timedifference ,604800);
					break;
			  case "d":
					$retval  = bcdiv( $timedifference,86400);
					break;
			  case "h":
					 $retval = bcdiv ($timedifference,3600);
					break;        
			  case "n":
					$retval  = bcdiv( $timedifference,60);
					break;        
			  case "s":
					$retval  = $timedifference;
					break;        
    	}    
   	return $retval;  
	}
	
	//-------------------------------------------------------------------------------------
	// DateAdd function for PHP
	//
	// Returns a date to which a specified time interval has been added." 
	// URL: http://www.phpbuilder.com/columns/akent20000610.php3?page=6
	//
	// Syntax: date_add(interval,number,date) 
 	//
	// Interval can be one of: 
	// yyyy     year
	//	q	Quarter
	// m	Month
	// y	Day of year
	// d	Day
	// w	Weekday
	// ww       Week of year
	// h	Hour
	// n	Minute
	// s	Second
	//
	// Sample: 
	// include('date_lib.lib.php');
	// $temptime = time();
	// echo strftime( "%Hh%M %A %d %b",$temptime);
	// $temptime =  DateAdd("n" ,50,$temptime);
	// echo "<p>";
	// echo strftime( "%Hh%M %A %d %b",$temptime);
	// 
	//-------------------------------------------------------------------------------------
	function date_add ($interval,  $number, $date)
	{

		$date_time_array  = getdate($date);
		
		$hours =  $date_time_array["hours"];
		$minutes =  $date_time_array["minutes"];
		$seconds =  $date_time_array["seconds"];
		$month =  $date_time_array["mon"];
		$day =  $date_time_array["mday"];
		$year =  $date_time_array["year"];

		 switch ($interval) {

			  case "yyyy":
					$year +=$number;
					break;        
			  case "q":
					$year +=($number*3);
					break;        
			  case "m":
					$month +=$number;
					break;        
			  case "y":
			  case "d":
			  case "w":
					 $day+=$number;
					break;        
			  case "ww":
					 $day+=($number*7);
					break;        
			  case "h":
					 $hours+=$number;
					break;        
			  case "n":
					 $minutes+=$number;
					break;        
			  case "s":
					 $seconds+=$number;
					break;        

		 }    
		$timestamp =  mktime($hours ,$minutes, $seconds,$month ,$day, $year);
		return $timestamp;
	}


	//-------------------------------------------------------------------------------------
	// takes a date[3] array, optionally a time[3] array to create a epoch timestamp
	//-------------------------------------------------------------------------------------
	function datestamp($date, $time = "")
	{
	  if (trim($time) == "")
	  {
			$time[0] = 0;
			$time[1] = 0;
		}    
		if ($date[0] == "") return "null";
		$datestamp = mktime(($time[0]+$time[2]),$time[1],0,$date[1],$date[0],$date[2]);
		return $datestamp;   
	}
	
	//-------------------------------------------------------------------------------------
	// display date relative to today
	//-------------------------------------------------------------------------------------
	function nicedate($date = "")
	{
	  	if (trim($date) == "" || $date == 0) return "&nbsp;";
		if (date("Ymd") == date("Ymd",$date)) $nicedate = date("g:i a",$date);    
		else if ((date("z") - date("z",$date)) < 6 && (date("z")-date("z",$date)) > 0) $nicedate = date("l g:i a",$date);    
		else $nicedate = date("M j",$date); 
		return $nicedate;   
	}
	
	//-------------------------------------------------------------------------------------
	// Calculate your age and display it on your page
	// echo "I'm <b>" . get_age("19861213") . "</b> years old!";
	//-------------------------------------------------------------------------------------
	function get_age($birthdate)
	{
	  // Note: $birthdate has to be format:
	  //       YYYYMMDD
	  $today = date("Ymd");
	  $age = floor(($today - $birthdate) / 10000);
	  return $age;
	 }
	
	
?>