<?php
/*
 * Database Management for PHP
 *
 * Copyright (c) 1998-2000 NetUSE AG
 *                    Boris Erdmann, Kristian Koehntopp
 *
 * $Id: db_mysql.inc,v 1.8 2001/10/12 16:16:16 layne_weathers Exp $
 *
 * http://phplib.sourceforge.net/documentation/documentation-3.html#ss3.1
 */ 

/*
	Modifications: 
			
			1. connection parameters -> $cfg[]
			2. add function "field" alias "f"
			3. all functions and proberies to lowercase
			4. Classname: "DB_Sql" -> "Database"
			5. Add paramter: $port
			6. add function insert_id()
*/

class Database
{
  
  /* public: connection parameters */
  var $host     = "localhost";
  var $port 	 = "3306";
  var $database = "";
  var $user     = "root";
  var $password = "";

  /* public: configuration parameters */
  var $auto_free     = 0;     ## Set to 1 for automatic mysql_free_result()
  var $debug         = 0;     ## Set to 1 for debugging messages.
  var $halt_on_error = "no"; 	## "yes" (halt with message), "no" (ignore errors quietly), "report" (ignore errror, but spit a warning)
  var $seq_table     = "db_sequence";

  /* public: result array and current row number */
  var $record   = array();
  var $row;

  /* public: current error number and error text */
  var $errno    = 0;
  var $error    = "";

  /* public: this is an api revision, not a CVS revision. */
  var $type     = "mysql";
  var $revision = "1.2";

  /* private: link and query handles */
  var $link_id  = 0;
  var $query_id = 0;
  


  /* public: constructor */
  function Database($query = "")
  {
  		global $cfg;
    	$this->host     = $cfg["db.host"];
    	$this->port 	 = $cfg["db.port"];
    	$this->database = $cfg["db.database"];
    	$this->user     = $cfg["db.username"];
  		$this->password = $cfg["db.password"];
  		
		$this->query($query);
  }

  /* public: some trivial reporting */
  function link_id() {
    return $this->link_id;
  }

  function query_id() {
    return $this->query_id;
  }

  /* public: connection management */
  function connect($database = "", $host = "", $user = "", $password = "", $port = "3306") {
    /* Handle defaults */
    if ("" == $database)
      $database = $this->database;
    if ("" == $host)
      $host     = $this->host;
    if ("" == $port)
      $port = $this->port;
    if ("" == $user)
      $user     = $this->user;
    if ("" == $password)
      $password = $this->password;
      
    /* establish connection, select database */
    if ($this->link_id == 0)
    {
      $this->link_id=mysql_pconnect("$host:$port", "$user", "$password");
      if (!$this->link_id) {
        $this->halt("pconnect($host:$port, $user) failed.");
        return 0;
      }

      if (!@mysql_select_db($database,$this->link_id)) {
        $this->halt("cannot use database ".$database);
        return 0;
      }
    }
    
    return $this->link_id;
  }

  /* public: discard the query result */
  function free() {
      @mysql_free_result($this->query_id);
      $this->query_id = 0;
  }

  /* public: perform a query */
  function query($Query_String) {
    /* No empty queries, please, since PHP4 chokes on them. */
    if ($Query_String == "")
      /* The empty query string is passed on from the constructor,
       * when calling the class without a query, e.g. in situations
       * like these: '$db = new DB_Sql_Subclass;'
       */
      return 0;

    if (!$this->connect()) {
      return 0; /* we already complained in connect() about that. */
    };

    # New query, discard previous result.
    if ($this->query_id) {
      $this->free();
    }

    if ($this->debug)
      printf("Debug: query = %s<br>\n", $Query_String);

    $this->query_id = @mysql_query($Query_String,$this->link_id);
    $this->row   = 0;
    $this->errno = mysql_errno();
    $this->error = mysql_error();
    if (!$this->query_id) {
      $this->halt("Invalid SQL: ".$Query_String);
    }

    # Will return nada if it fails. That's fine.
    return $this->query_id;
  }

  /* public: walk result set */
  function next_record() {
    if (!$this->query_id) {
      $this->halt("next_record called with no query pending.");
      return 0;
    }

    $this->record = @mysql_fetch_array($this->query_id);
    $this->row   += 1;
    $this->errno  = mysql_errno();
    $this->error  = mysql_error();

    $stat = is_array($this->record);
    if (!$stat && $this->auto_free) {
      $this->free();
    }
    return $stat;
  }

  /* public: position in result set */
  function seek($pos = 0)
  {
    $status = @mysql_data_seek($this->query_id, $pos);
    if ($status)
      $this->Row = $pos;
    else
    {
      $this->halt("seek($pos) failed: result has ".$this->num_rows()." rows.");

      /* half assed attempt to save the day, 
       * but do not consider this documented or even
       * desireable behaviour.
       */
      @mysql_data_seek($this->query_id, $this->num_rows());
      $this->Row = $this->num_rows();
      return 0;
    }

    return 1;
  }

  /* public: table locking */
  function lock($table, $mode = "write")
  {
    $query = "lock tables ";
    if (is_array($table)) {
      while (list($key,$value) = each($table)) {
        if (!is_int($key)) {
		  // texts key are "read", "read local", "write", "low priority write"
          $query .= "$value $key, ";
        } else {
          $query .= "$value $mode, ";
        }
      }
      $query = substr($query,0,-2);
    } else {
      $query .= "$table $mode";
    }
    $res = $this->query($query);
	if (!$res) {
      $this->halt("lock() failed.");
      return 0;
    }
    return $res;
  }
  
  function unlock()
  {
    $res = $this->query("unlock tables");
    if (!$res) {
      $this->halt("unlock() failed.");
    }
    return $res;
  }

  /* public: evaluate the result (size, width) */
  function insert_id() {
    return @mysql_insert_id($this->link_id);
  }
  
  function affected_rows() {
    return @mysql_affected_rows($this->link_id);
  }

  function num_rows() {
    return @mysql_num_rows($this->query_id);
  }

  function num_fields() {
    return @mysql_num_fields($this->query_id);
  }

  /* public: shorthand notation */
  function nf() {
    return $this->num_rows();
  }

  function np() {
    print $this->num_rows();
  }

	/* added  "f" -> "field" */
  function field($Name) {
    if (isset($this->record[$Name])) {
      return $this->record[$Name];
    }
  }

  function f($Name) {
    if (isset($this->record[$Name])) {
      return $this->record[$Name];
    }
  }
  
  function p($Name) {
    if (isset($this->record[$Name])) {
      print $this->record[$Name];
    }
  }

  /* public: sequence numbers */
  function nextid($seq_name) {
    $this->connect();
    
    if ($this->lock($this->seq_table)) {
      /* get sequence number (locked) and increment */
      $q  = sprintf("select nextid from %s where seq_name = '%s'",
                $this->seq_table,
                $seq_name);
      $id  = @mysql_query($q, $this->link_id);
      $res = @mysql_fetch_array($id);
      
      /* No current value, make one */
      if (!is_array($res)) {
        $currentid = 0;
        $q = sprintf("insert into %s values('%s', %s)",
                 $this->seq_table,
                 $seq_name,
                 $currentid);
        $id = @mysql_query($q, $this->link_id);
      } else {
        $currentid = $res["nextid"];
      }
      $nextid = $currentid + 1;
      $q = sprintf("update %s set nextid = '%s' where seq_name = '%s'",
               $this->seq_table,
               $nextid,
               $seq_name);
      $id = @mysql_query($q, $this->link_id);
      $this->unlock();
    } else {
      $this->halt("cannot lock ".$this->seq_table." - has it been created?");
      return 0;
    }
    return $nextid;
  }

  /* public: return table metadata */
  function metadata($table = "", $full = false) {
    $count = 0;
    $id    = 0;
    $res   = array();

    /*
     * Due to compatibility problems with Table we changed the behavior
     * of metadata();
     * depending on $full, metadata returns the following values:
     *
     * - full is false (default):
     * $result[]:
     *   [0]["table"]  table name
     *   [0]["name"]   field name
     *   [0]["type"]   field type
     *   [0]["len"]    field length
     *   [0]["flags"]  field flags
     *
     * - full is true
     * $result[]:
     *   ["num_fields"] number of metadata records
     *   [0]["table"]  table name
     *   [0]["name"]   field name
     *   [0]["type"]   field type
     *   [0]["len"]    field length
     *   [0]["flags"]  field flags
     *   ["meta"][field name]  index of field named "field name"
     *   This last one could be used if you have a field name, but no index.
     *   Test:  if (isset($result['meta']['myfield'])) { ...
     */

    // if no $table specified, assume that we are working with a query
    // result
    if ($table) {
      $this->connect();
      $id = @mysql_list_fields($this->database, $table);
      if (!$id) {
        $this->halt("Metadata query failed.");
        return false;
      }
    } else {
      $id = $this->query_id; 
      if (!$id) {
        $this->halt("No query specified.");
        return false;
      }
    }
 
    $count = @mysql_num_fields($id);

    // made this IF due to performance (one if is faster than $count if's)
    if (!$full) {
      for ($i=0; $i<$count; $i++) {
        $res[$i]["table"] = @mysql_field_table ($id, $i);
        $res[$i]["name"]  = @mysql_field_name  ($id, $i);
        $res[$i]["type"]  = @mysql_field_type  ($id, $i);
        $res[$i]["len"]   = @mysql_field_len   ($id, $i);
        $res[$i]["flags"] = @mysql_field_flags ($id, $i);
      }
    } else { // full
      $res["num_fields"]= $count;
    
      for ($i=0; $i<$count; $i++) {
        $res[$i]["table"] = @mysql_field_table ($id, $i);
        $res[$i]["name"]  = @mysql_field_name  ($id, $i);
        $res[$i]["type"]  = @mysql_field_type  ($id, $i);
        $res[$i]["len"]   = @mysql_field_len   ($id, $i);
        $res[$i]["flags"] = @mysql_field_flags ($id, $i);
        $res["meta"][$res[$i]["name"]] = $i;
      }
    }
    
    // free the result only if we were called on a table
    if ($table) {
      @mysql_free_result($id);
    }
    return $res;
  }

  /* public: find available table names */
  function table_names() {
    $this->connect();
    $h = @mysql_query("show tables", $this->link_id);
    $i = 0;
    while ($info = @mysql_fetch_row($h)) {
      $return[$i]["table_name"]      = $info[0];
      $return[$i]["tablespace_name"] = $this->database;
      $return[$i]["database"]        = $this->database;
      $i++;
    }
    
    @mysql_free_result($h);
    return $return;
  }

  /* private: error handling */
  function halt($msg) {
    $this->error = @mysql_error($this->link_id);
    $this->errno = @mysql_errno($this->link_id);
    if ($this->halt_on_error == "no")
      return;

    $this->haltmsg($msg);

    if ($this->halt_on_error != "report")
      die("Session halted.");
  }

  function haltmsg($msg) {
    printf("</td></tr></table><b>Database error:</b> %s<br>\n", $msg);
    printf("<b>MySQL Error</b>: %s (%s)<br>\n",
      $this->errno,
      $this->error);
  }

}
?>
