<?php

require("lib/session.config.php");
require("lib/session_db.lib.php");

/*

Session handler: version 1.0BETA
scott@furt.com
http://furt.com/code/php/session/

reqires:
  main.php	- for error handling and $Svar[]
  db.php	- for all db_* functions

*/


// setup session with current cookie (if present)
// and returns the session object
function init_session() {
  global $cookie_sid;

  $s = new Session( $cookie_sid );
  if ($s->err == 1) {
	return errorcat("Could not initialize session!");
  }

  return $s;
}


/*

  The Session class:
  	Responsible for creating a new session, or loading an existing
  	session from the database.  stores the current session ID in a
  	cookie (pc_cookie_sid)

*/

class Session
{
  var $table 	= "session";	// table where session data is stored

  var $sid 		= 0;			// session ID
  var $sdata	= array();	// session data (the full database record)

  var $name 	= '';			// username attached to this session
  var $data 	= array();		// data (stored as serialized array in database)

  var $dbg		= 0;			// print debugging stuff?? (0=no, 1=yes)

  var $err		= 1;			// error status (0=no error, 1=error)

  // 15 min.
  var $expire	= 900;		// how long our cookies/db entries hang around for
  									// day=86400, month=2592000
									
  var $gc_pct	= 10;			// percent chance of garbage collection (CleanUp)
  									// 0 for never, 100 for always,



	/*
	  The core... this function is the session initializer.
			Responsible for building/retrieving the session information
	*/

	function Session ( $req_id=0 ) {
	  global $Svar;

	  $this->sid = $req_id;		// requested sid, or 0 if new session

	  $current   = time();		// current time

	  if ($this->dbg) { print "Session start...<BR>\n"; }

	  // Try and connect to the database
	  // function is in: db.php
	  if (!db_connect()) {
		errorcat("Session: Unable to connect to database");
		return 0;
	  }

	  // the user doesnt have a session ID, create one
	  if (!$this->sid) {

		// the sid will be a md5 hash of the current time
		// and a random integer between 0 and 100
		//$this->sid = md5( $current . rand(0,100) );
		$this->sid = md5 (uniqid (rand())); 

		if ($this->dbg) { print "No id requested, creating new ($this->sid)<BR>\n"; }

		$r = db_query("
			INSERT INTO ". $this->table ."
			(session_id,lastused)
			VALUES (".
				db_quote($this->sid) .",
				$current
			)
		");
		if (!$r) {
			errorcat("Session: Cannot insert new sid:(". $this->sid .") into db");
		}

		if ($this->dbg) { print "Setting cookie for (". $this->sid .")<BR>\n"; }

		// Save SID as cookie
		$this->save_cookie();

		if ($this->dbg) { print "Session ID created OK <BR>\n"; }

		if ($this->dbg) { print "Session done...<BR>\n<BR>\n"; }

		// session created OK, turn off error flag
		$this->err = 0;
		return;
	  }
	  // ----- finished creating new ID -----



	  if ($this->dbg) { print "Existing session id requested: (". $this->sid .")<BR>\n"; }



	  // requesting existing session, load the info from the DB into
	  // our session data variable
	  $this->sdata = db_query_hash("
		SELECT *
		FROM ". $this->table ."
		WHERE session_id=". db_quote($this->sid) ."
	  ");
	  if ( !is_array($this->sdata) ) {
		if ($this->dbg) { print "Session ID requested was not found in the database!<BR>\n"; }
		// if the data cannot be found in the database
		// give the user a new session
		$this->err = 0;
		return new Session(0);
	  }
	  // ----- finished loading session data -----


	  // set the special name variable to the name in the database (if exists)
	  $this->name = $this->sdata["name"];

	  // set the special data array to the serialized data in the DB
	  if ($this->sdata['data']) {
		if ($this->dbg) { print "Unserializing 'data' array (". $this->sdata['data'] .")<BR>\n"; }
		$this->data = unserialize($this->sdata['data']);

		if (is_array($this->data)) {
			if ($this->dbg) {
			while(list($k,$v) = each($this->data)) {
				print "..... $k = $v<BR>";
			}
			}
			reset ($this->data);
		}
		else {
			$this->data = array();
		}


	  }


	  if ($this->dbg) { print "Session ID found in the database<BR>\n"; }


	  // verify that this data is fresh and tasty
	  if ( !$this->verify_time() ) {
		if ($this->dbg) { print "Verifying timestamp<BR>\n"; }
		// if the data is very old
		// give the user a new session
		$this->err = 0;
		return new Session(0);
	  }


	  if ($this->dbg) { print "Setting cookie for (". $this->sid .")<BR>\n"; }

	  // Save SID as cookie
	  $this->save_cookie();


	  // reset 'lastused' timestamp in database
	  //$this->ResetTime();
	  $this->update('lastused', time());


	  // evaluate the chance for garbage collection
	  if ( rand(0, 99) < $this->gc_pct ) {
		$this->clean_up();	// remove expired sessions
	  }


	  if ($this->dbg) { print "Session done...<BR>\n<BR>\n"; }

	  $this->err = 0;
	  return;
	}


	function save_cookie() {

	  // when will this cookie/data expire?
	  $expire    = time() + $this->expire;

	  // Save the SID as a cookie
	  SetCookie('cookie_sid', $this->sid, $expire, '/');

	  return 1;
	}




	function update( $name,$value='' ) {
	  global $Svar;

	  // make sure to update the special 'name' variable
	  if ($name == 'name') {
		$this->name = $value;
	  }
	  // serialize the 'data' array
	  if ($name == 'data') {
		$value = serialize($this->data);
	  }

	  if ($this->dbg) { print "Updating [$name] = [$value]<BR>\n"; }

	  $r = db_query("
		UPDATE ". $this->table ."
		SET $name=". db_quote($value) ."
		WHERE session_id=". db_quote($this->sid) ."
	  ");
	  if (!$r) {
		return errorcat("Unable to update ($name) with ($value)");
	  }

	  // make sure that 'sdata' is an array()
	  if ( !is_array($this->sdata) ) {
		$this->sdata = array();
	  }
	  // update our Session object
	  $this->sdata[$name] = $value;

	  if ($this->dbg) { print "Updated OK (database and s->sdata[])<BR>\n"; }

	  return 1;
	}




	function verify_time() {
	  global $Svar;

	  if ($this->dbg) { print "Verifying session time<BR>\n"; }

	  // make sure our session isnt expired
	  // (if, for some strange reason, the cookie hangs around
	  //   longer than the entry in our database)
	  if ( ($this->sdata["lastused"] + $this->expire) < time() ) {
		if ($this->dbg) { print "icky time... too old, return 0<BR>\n"; }
		return 0;
	  }

	  if ($this->dbg) { print "Verified OK (time is recent)<BR>\n"; }
	  return 1;
	}


	// Garbage collection, deletes old entries in the database
	// only run periodically (see $gc_pct variable)
	function clean_up() {
	  global $Svar;

	  $still_valid = time() - $this->expire;

	  if ($this->dbg) { print "Cleaning up sessions older than (". $still_valid .")<BR>\n"; }

	  $r = db_query("
		DELETE FROM ". $Svar['t_session'] ."
		WHERE lastused < $still_valid
	  ");
	  if (!$r) {
		return errorcat("Unable to CleanUp the database");
	  }

	  return 1;
	}






	// Attach a user name to an SID
	//   (for after a user login) to keep easy track of the current
	//    user's login name
	function register_name($name) {

	  if (!$this->update('name', $name)) {
		return errorcat("register_name failed!");
	  }

	  return 1;
	}

	// alias to $this->update('data')
	// update the database with the contents of 'data'
	function update_data() {
	  $this->update('data',$this->data);
	  return 1;
	}


	// cleans out all data associated with this session
	function clean_session() {

	  $this->register_name('');
	  $this->data = array();
	  $this->update_data();

	  return 1;
	}



}#class end
?>
